Plan

Struct Plan 

pub struct Plan<'a> {
    pub first: i32,
    pub last: i32,
    pub reason: Option<&'a str>,
}
The Plan tells how many tests will be run, or how many tests have run.

Fields

first: i32

ID of first planned test. Should always start with 1.

last: i32

ID of last planned test. A value of 0 should indicate no tests were executed.

reason: Option<&'a str>

Arbitrary string which should indicate why the certain tests were skipped.

Implementations

Source

impl<'a> Plan<'a>

pub fn parse_from_str(content: &'a str) -> Result<Self>

Parse Plan from a &str.

Examples

Parsing a TAP plan may look like this:

use tapconsooomer::Plan;

let content = "1..5 # TODO: Test 3 may fail";
let plan = Plan::parse_from_str(content).expect("Parser error");
assert_eq!(plan.first, 1);
assert_eq!(plan.last, 5);
assert_eq!(plan.reason, Some("TODO: Test 3 may fail"));

Note, Plan::reason is optional:

use tapconsooomer::Plan;

let content = "1..5";
let plan = Plan::parse_from_str(content).expect("Parser error");
assert_eq!(plan.first, 1);
assert_eq!(plan.last, 5);
assert_eq!(plan.reason, None);