Crate tapconsooomer
Source - BailOut
- Marks an emergency exit of the test procedure.
- Body
- The body of the TAP document.
- Directive
- A
Directive gives some meta-data about the execution of a Test. - Document
- A
Document represents the root of any TAP document. It’s the main point of interaction for users of this API. - Plan
- The
Plan tells how many tests will be run, or how many tests have run. - Pragma
- A
Pragma provides information to the document parser/interpreter. - Preamble
- The TAP
Preamble declares the start of a TAP document. - Subtest
Subtests provide a way to nest one TAP14 stream inside another. This may be used in a variety of ways, depending on
the test harness.- TAPParser
- Test
- A
Test declaring the result of some test-case.
- Key
- Directive keys supported by
Directive. - Rule
- Statement
- An enumeration of all possible TAP constructs that can be part of a
Body.